from distutils.version import LooseVersion

from django.conf import settings

ENABLE_SELECT2 = getattr(settings, 'DJANGOCMS_LINK_USE_SELECT2', False)

if ENABLE_SELECT2 and 'django_select2' in settings.INSTALLED_APPS:
    import django_select2

    select2_version = LooseVersion(django_select2.__version__)
    if select2_version >= LooseVersion('5'):
        from djangocms_link.fields_select2 import Select2PageSearchField as PageSearchField
    else:
        from djangocms_link.fields_select2_legacy import Select2LegacyPageSearchField as PageSearchField
else:
    from cms.forms.fields import PageSelectFormField as PageSearchField



from djangocms_helper.base_test import BaseTestCase
from djangocms_link.fields import PageSearchField
from djangocms_link.fields_select2 import Select2PageSearchField


class FieldTestCase(BaseTestCase):
    def test_field_with_django_select2_extension(self):
        self.assertEqual(PageSearchField, Select2PageSearchField)



from cms.models import Page
from django import forms

from django_select2.forms import ModelSelect2Widget


class Select2PageSearchFieldMixin(object):
    search_fields = [
        'title_set__title__icontains',
        'title_set__menu_title__icontains',
        'title_set__slug__icontains'
    ]


class Select2PageSelectWidget(Select2PageSearchFieldMixin, ModelSelect2Widget):
    site = None

    def get_queryset(self):
        if self.site:
            return Page.objects.drafts().on_site(self.site)
        return Page.objects.drafts()


class Select2PageSearchField(forms.ModelChoiceField):
    widget = Select2PageSelectWidget()

    def __init__(self, *args, **kwargs):
        kwargs['queryset'] = self.widget.get_queryset()
        super(Select2PageSearchField, self).__init__(*args, **kwargs)



from cms.models import Page
from django_select2.fields import AutoModelSelect2Field


class Select2LegacyPageSearchField(AutoModelSelect2Field):
    site = None
    search_fields = [
        'title_set__title__icontains',
        'title_set__menu_title__icontains',
        'title_set__slug__icontains'
    ]

    def get_queryset(self):
        if self.site:
            return Page.objects.drafts().on_site(self.site)
        return Page.objects.drafts()

    def security_check(self, request, *args, **kwargs):
        user = request.user

        if user and not user.is_anonymous() and user.is_staff:
            return True
        return False



# -*- coding: utf-8 -*-
from django.conf import settings
from django.utils.translation import ugettext_lazy as _
from django.contrib.sites.models import Site

from cms.plugin_base import CMSPluginBase
from cms.plugin_pool import plugin_pool

from .forms import LinkForm
from .models import Link


class LinkPlugin(CMSPluginBase):
    model = Link
    form = LinkForm
    name = _('Link')
    text_enabled = True
    allow_children = True

    fieldsets = [
        (None, {
            'fields': (
                'name',
                ('external_link', 'internal_link'),
            )
        }),
        (_('Link settings'), {
            'classes': ('collapse',),
            'fields': (
                ('mailto', 'phone'),
                ('anchor', 'target'),
            )
        }),
        (_('Advanced settings'), {
            'classes': ('collapse',),
            'fields': (
                'template',
                'attributes',
            )
        }),
    ]

    def get_render_template(self, context, instance, placeholder):
        return 'djangocms_link/{}/link.html'.format(instance.template)

    def render(self, context, instance, placeholder):
        context['link'] = instance.get_link()
        return super(LinkPlugin, self).render(context, instance, placeholder)

    def get_form(self, request, obj=None, **kwargs):
        form_class = super(LinkPlugin, self).get_form(request, obj, **kwargs)

        if obj and obj.page and obj.page.site:
            site = obj.page.site
        elif self.page and self.page.site:
            site = self.page.site
        else:
            # this might NOT give the result you expect
            site = Site.objects.get_current()

        class Form(form_class):
            def __init__(self, *args, **kwargs):
                super(Form, self).__init__(*args, **kwargs)
                self.for_site(site)

        return Form


plugin_pool.register_plugin(LinkPlugin)
